==> qt5-tools-debuginfo-5.9.2-1.tar.xz: usr/src/debug/qt5-tools-5.9.2-1/src/designer/src/components/lib/.rcc/qrc_propertyeditor.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.2
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.2-1.i686/src/qttools-opensource-src-5.9.2/src/designer/src/components/propertyeditor/fontmapping.xml
  0x0,0x0,0x3,0xb,
  0x0,
  0x0,0xd,0xe9,0x78,0x9c,0xed,0x96,0x61,0x4f,0xdb,0x30,0x10,0x86,0xbf,0xf3,0x2b,
  0x6e,0x15,0x9a,0xb6,0x89,0x24,0x30,0xa4,0x69,0x62,0xa5,0x68,0x94,0x50,0x21,0x75,
  0x5d,0x11,0x81,0xd,0x21,0x84,0xdc,0xe4,0xda,0x7a,0x38,0x76,0x6a,0x3b,0xd,0xfd,
  0xf7,0x3b,0x27,0x29,0x2d,0xac,0x9d,0x34,0x9,0x4d,0x7c,0x68,0x54,0xa9,0x95,0xef,
  0xf5,0x73,0xe7,0xf7,0x7c,0x51,0x9b,0x47,0xf,0xa9,0x80,0x29,0x6a,0xc3,0x95,0x3c,
  0x6c,0xec,0xf9,0xbb,0xd,0x40,0x19,0xab,0x84,0xcb,0xd1,0x61,0xe3,0x32,0x3a,0xf5,
  0x3e,0x37,0x8e,0x5a,0x5b,0x5b,0xcd,0x37,0x9e,0xf7,0xe1,0x5,0x9f,0xad,0xf2,0x3,
  0x6d,0x95,0xcd,0x34,0x1f,0x8d,0x2d,0xbc,0x6b,0xbf,0x87,0x8f,0xbb,0x7b,0x9f,0x20,
  0x1a,0x23,0x9c,0x5b,0x8a,0xa4,0x19,0x93,0x33,0xe8,0xda,0xc4,0xaf,0x94,0xd2,0xb2,
  0xd8,0x1e,0xc0,0xd8,0xda,0xcc,0x1c,0x4,0x41,0x51,0x14,0xfe,0xc4,0xfa,0x5c,0x5,
  0x82,0xc7,0x28,0xd,0x15,0x1c,0xd4,0xd4,0x68,0xcc,0xd,0xc,0xb9,0x40,0xa0,0xef,
  0x8c,0x69,0xb,0x6a,0x8,0xb6,0xe2,0x76,0x49,0x97,0x73,0x63,0x21,0x55,0x49,0x4e,
  0x8a,0x45,0x24,0x52,0x4a,0xdc,0x73,0xeb,0xd7,0x90,0xed,0xf3,0xe8,0xee,0x38,0xec,
  0x9c,0xf5,0xee,0xba,0x67,0xed,0xb0,0x77,0x11,0x1e,0x74,0xfa,0x5d,0x2f,0xfc,0xd9,
  0xe,0xfb,0xd1,0x76,0x55,0x51,0x9a,0xa2,0x8e,0x39,0x13,0x4,0x75,0x15,0x20,0x5c,
  0x1a,0x36,0x42,0x17,0xab,0x17,0xd0,0xc0,0x58,0x9,0xe7,0x25,0x4c,0x99,0xe0,0x9,
  0xc4,0x8b,0x3d,0x94,0xb1,0x2a,0x9c,0x44,0x29,0x9b,0x41,0x4e,0xfb,0xed,0xa2,0x70,
  0xe9,0x30,0x2c,0x8e,0x95,0x4e,0x98,0x8c,0x11,0xa,0x6e,0xc7,0x65,0xa5,0x4b,0x88,
  0x7a,0x3f,0xb0,0x91,0x46,0x4c,0x51,0x5a,0xc8,0xb4,0x9a,0xf2,0x4,0x93,0x47,0xb9,
  0xa3,0x5c,0xa8,0xa1,0x2d,0x98,0xa6,0xb3,0xea,0x1d,0x60,0xc2,0xa2,0x96,0xcc,0xf2,
  0x29,0x8a,0xd9,0xe,0xe5,0x59,0x99,0x84,0x34,0xa9,0xa1,0x54,0xe4,0x39,0x97,0x84,
  0xab,0xcb,0x81,0x42,0x73,0x6b,0x51,0x2e,0x65,0x1c,0xa0,0x2d,0x90,0x56,0x66,0x2a,
  0x7,0x26,0x93,0x67,0xed,0xf3,0xe1,0x54,0x69,0x78,0x6c,0x50,0xc5,0x2d,0x51,0xd2,
  0x99,0x21,0x13,0x6e,0xe9,0xde,0x19,0x20,0xab,0x56,0x34,0xb6,0x54,0x7b,0xb,0x59,
  0x45,0x1b,0xe6,0x9a,0x4a,0xd4,0x8e,0xc2,0xe5,0x50,0xe9,0x94,0xb9,0x60,0xed,0x1f,
  0x56,0x45,0xc7,0x16,0x5c,0x4,0x98,0x5d,0x81,0xad,0x15,0x5e,0x6e,0xe6,0xbd,0xee,
  0xf4,0x2e,0xa1,0x83,0x12,0x35,0x99,0xda,0xcf,0x7,0x54,0xef,0x9f,0x2d,0xfd,0xfa,
  0xd4,0xb8,0x45,0xab,0x5c,0xf3,0x6,0xe8,0xf2,0x27,0x90,0xcb,0x4,0xf5,0x92,0x83,
  0xf5,0xed,0x22,0x7e,0x99,0x66,0x75,0x8a,0x7a,0xfa,0x60,0x1f,0x18,0x5d,0x57,0x17,
  0x33,0x63,0x62,0xd,0x66,0xe5,0xde,0x53,0x72,0xfa,0xb1,0x85,0x8e,0x72,0xaa,0x28,
  0x4b,0x75,0xe6,0xb2,0x5f,0xf8,0x10,0x63,0x56,0xd9,0x48,0xfb,0x59,0x96,0x21,0xd3,
  0xce,0x6b,0x6a,0xad,0xdb,0x5f,0xd6,0x58,0x5f,0x61,0x9f,0xae,0xf0,0x7e,0x7d,0x87,
  0x2b,0xff,0x62,0x91,0x27,0x65,0x7f,0x4b,0x6d,0xc6,0xe2,0x7b,0x36,0x72,0x9b,0xcb,
  0xc2,0xeb,0x13,0xfa,0xd0,0x17,0xc8,0xa8,0x50,0x8d,0x53,0x8e,0x45,0x45,0x55,0x42,
  0xa8,0x82,0x94,0xcf,0xdb,0x60,0x15,0xbd,0x3f,0x4c,0xae,0x71,0x7e,0xf0,0x75,0xa7,
  0xd6,0x38,0xc9,0xb9,0x2e,0x2f,0x91,0xa1,0x83,0x8,0xe1,0x48,0xe4,0x63,0x8a,0xcf,
  0x86,0x7c,0x24,0x73,0x5f,0xe9,0x51,0x30,0x9f,0x96,0x60,0x94,0x9,0x6f,0xdf,0xdf,
  0xf5,0xc7,0x36,0x15,0xcb,0xd3,0x1a,0xf6,0x4e,0xe6,0xb3,0xba,0x5d,0x2d,0xbf,0xdc,
  0xe3,0x79,0xe5,0x4b,0xf0,0xe4,0x7b,0x3b,0xba,0xee,0x87,0x74,0x7c,0x69,0x53,0xb2,
  0xda,0x19,0x70,0x43,0xeb,0x61,0x2f,0x3a,0x8b,0xae,0x81,0x46,0xa8,0xf1,0x83,0xcb,
  0x44,0x15,0x6,0xda,0x61,0x3,0x5a,0x8b,0xd0,0x84,0x42,0x34,0x17,0x61,0x3a,0xc0,
  0x84,0x1c,0x77,0xb1,0x5b,0x87,0x5c,0x22,0x19,0x92,0xd7,0x3f,0x5b,0xcd,0x21,0x4b,
  0xb9,0x98,0xb5,0x4e,0xf0,0x17,0xbb,0xca,0xe1,0x82,0x49,0xd3,0xc,0xea,0xb5,0x66,
  0xc2,0x4d,0x26,0xd8,0x93,0x20,0xdc,0xbc,0x9d,0xe0,0x97,0xdb,0x66,0x30,0x8f,0x35,
  0x83,0x39,0x6a,0x3,0x5d,0xf,0x85,0x6f,0x4a,0xaa,0xbf,0x93,0x9d,0x62,0x83,0x7f,
  0x69,0x3c,0x6a,0x3e,0x5c,0x8f,0x76,0xd1,0xd,0xf6,0x5f,0xb1,0xc7,0xdc,0x1a,0xab,
  0x91,0xa5,0x70,0x45,0x2f,0xdc,0x35,0x43,0xb3,0x42,0xb4,0x49,0xf2,0x5f,0x93,0xac,
  0x19,0xab,0x75,0xca,0x4d,0xba,0xd7,0x92,0x6e,0xf5,0xb8,0xae,0x52,0xbd,0x86,0x34,
  0xc1,0xd3,0x7f,0x16,0xbf,0x1,0xfd,0x7f,0xbd,0x50,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // propertyeditor
  0x0,0xe,
  0xd,0x76,0x85,0xe2,
  0x0,0x70,
  0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x79,0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // fontmapping.xml
  0x0,0xf,
  0x7,0x30,0xe4,0x7c,
  0x0,0x66,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor/fontmapping.xml
  0x0,0x0,0x0,0x44,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5e,0xc7,0xb5,0xc8,0xc8,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)(); }
   } dummy;
}

==> qt5-tools-debuginfo-5.9.3-1.tar.xz: usr/src/debug/qt5-tools-5.9.3-1/src/designer/src/components/lib/.rcc/qrc_propertyeditor.cpp <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 5.9.3
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/qt5-tools/qt5-tools-5.9.3-1.x86_64/src/qttools-opensource-src-5.9.3/src/designer/src/components/propertyeditor/fontmapping.xml
  0x0,0x0,0x3,0xb,
  0x0,
  0x0,0xd,0xe9,0x78,0x9c,0xed,0x96,0x61,0x4f,0xdb,0x30,0x10,0x86,0xbf,0xf3,0x2b,
  0x6e,0x15,0x9a,0xb6,0x89,0x24,0x30,0xa4,0x69,0x62,0xa5,0x68,0x94,0x50,0x21,0x75,
  0x5d,0x11,0x81,0xd,0x21,0x84,0xdc,0xe4,0xda,0x7a,0x38,0x76,0x6a,0x3b,0xd,0xfd,
  0xf7,0x3b,0x27,0x29,0x2d,0xac,0x9d,0x34,0x9,0x4d,0x7c,0x68,0x54,0xa9,0x95,0xef,
  0xf5,0x73,0xe7,0xf7,0x7c,0x51,0x9b,0x47,0xf,0xa9,0x80,0x29,0x6a,0xc3,0x95,0x3c,
  0x6c,0xec,0xf9,0xbb,0xd,0x40,0x19,0xab,0x84,0xcb,0xd1,0x61,0xe3,0x32,0x3a,0xf5,
  0x3e,0x37,0x8e,0x5a,0x5b,0x5b,0xcd,0x37,0x9e,0xf7,0xe1,0x5,0x9f,0xad,0xf2,0x3,
  0x6d,0x95,0xcd,0x34,0x1f,0x8d,0x2d,0xbc,0x6b,0xbf,0x87,0x8f,0xbb,0x7b,0x9f,0x20,
  0x1a,0x23,0x9c,0x5b,0x8a,0xa4,0x19,0x93,0x33,0xe8,0xda,0xc4,0xaf,0x94,0xd2,0xb2,
  0xd8,0x1e,0xc0,0xd8,0xda,0xcc,0x1c,0x4,0x41,0x51,0x14,0xfe,0xc4,0xfa,0x5c,0x5,
  0x82,0xc7,0x28,0xd,0x15,0x1c,0xd4,0xd4,0x68,0xcc,0xd,0xc,0xb9,0x40,0xa0,0xef,
  0x8c,0x69,0xb,0x6a,0x8,0xb6,0xe2,0x76,0x49,0x97,0x73,0x63,0x21,0x55,0x49,0x4e,
  0x8a,0x45,0x24,0x52,0x4a,0xdc,0x73,0xeb,0xd7,0x90,0xed,0xf3,0xe8,0xee,0x38,0xec,
  0x9c,0xf5,0xee,0xba,0x67,0xed,0xb0,0x77,0x11,0x1e,0x74,0xfa,0x5d,0x2f,0xfc,0xd9,
  0xe,0xfb,0xd1,0x76,0x55,0x51,0x9a,0xa2,0x8e,0x39,0x13,0x4,0x75,0x15,0x20,0x5c,
  0x1a,0x36,0x42,0x17,0xab,0x17,0xd0,0xc0,0x58,0x9,0xe7,0x25,0x4c,0x99,0xe0,0x9,
  0xc4,0x8b,0x3d,0x94,0xb1,0x2a,0x9c,0x44,0x29,0x9b,0x41,0x4e,0xfb,0xed,0xa2,0x70,
  0xe9,0x30,0x2c,0x8e,0x95,0x4e,0x98,0x8c,0x11,0xa,0x6e,0xc7,0x65,0xa5,0x4b,0x88,
  0x7a,0x3f,0xb0,0x91,0x46,0x4c,0x51,0x5a,0xc8,0xb4,0x9a,0xf2,0x4,0x93,0x47,0xb9,
  0xa3,0x5c,0xa8,0xa1,0x2d,0x98,0xa6,0xb3,0xea,0x1d,0x60,0xc2,0xa2,0x96,0xcc,0xf2,
  0x29,0x8a,0xd9,0xe,0xe5,0x59,0x99,0x84,0x34,0xa9,0xa1,0x54,0xe4,0x39,0x97,0x84,
  0xab,0xcb,0x81,0x42,0x73,0x6b,0x51,0x2e,0x65,0x1c,0xa0,0x2d,0x90,0x56,0x66,0x2a,
  0x7,0x26,0x93,0x67,0xed,0xf3,0xe1,0x54,0x69,0x78,0x6c,0x50,0xc5,0x2d,0x51,0xd2,
  0x99,0x21,0x13,0x6e,0xe9,0xde,0x19,0x20,0xab,0x56,0x34,0xb6,0x54,0x7b,0xb,0x59,
  0x45,0x1b,0xe6,0x9a,0x4a,0xd4,0x8e,0xc2,0xe5,0x50,0xe9,0x94,0xb9,0x60,0xed,0x1f,
  0x56,0x45,0xc7,0x16,0x5c,0x4,0x98,0x5d,0x81,0xad,0x15,0x5e,0x6e,0xe6,0xbd,0xee,
  0xf4,0x2e,0xa1,0x83,0x12,0x35,0x99,0xda,0xcf,0x7,0x54,0xef,0x9f,0x2d,0xfd,0xfa,
  0xd4,0xb8,0x45,0xab,0x5c,0xf3,0x6,0xe8,0xf2,0x27,0x90,0xcb,0x4,0xf5,0x92,0x83,
  0xf5,0xed,0x22,0x7e,0x99,0x66,0x75,0x8a,0x7a,0xfa,0x60,0x1f,0x18,0x5d,0x57,0x17,
  0x33,0x63,0x62,0xd,0x66,0xe5,0xde,0x53,0x72,0xfa,0xb1,0x85,0x8e,0x72,0xaa,0x28,
  0x4b,0x75,0xe6,0xb2,0x5f,0xf8,0x10,0x63,0x56,0xd9,0x48,0xfb,0x59,0x96,0x21,0xd3,
  0xce,0x6b,0x6a,0xad,0xdb,0x5f,0xd6,0x58,0x5f,0x61,0x9f,0xae,0xf0,0x7e,0x7d,0x87,
  0x2b,0xff,0x62,0x91,0x27,0x65,0x7f,0x4b,0x6d,0xc6,0xe2,0x7b,0x36,0x72,0x9b,0xcb,
  0xc2,0xeb,0x13,0xfa,0xd0,0x17,0xc8,0xa8,0x50,0x8d,0x53,0x8e,0x45,0x45,0x55,0x42,
  0xa8,0x82,0x94,0xcf,0xdb,0x60,0x15,0xbd,0x3f,0x4c,0xae,0x71,0x7e,0xf0,0x75,0xa7,
  0xd6,0x38,0xc9,0xb9,0x2e,0x2f,0x91,0xa1,0x83,0x8,0xe1,0x48,0xe4,0x63,0x8a,0xcf,
  0x86,0x7c,0x24,0x73,0x5f,0xe9,0x51,0x30,0x9f,0x96,0x60,0x94,0x9,0x6f,0xdf,0xdf,
  0xf5,0xc7,0x36,0x15,0xcb,0xd3,0x1a,0xf6,0x4e,0xe6,0xb3,0xba,0x5d,0x2d,0xbf,0xdc,
  0xe3,0x79,0xe5,0x4b,0xf0,0xe4,0x7b,0x3b,0xba,0xee,0x87,0x74,0x7c,0x69,0x53,0xb2,
  0xda,0x19,0x70,0x43,0xeb,0x61,0x2f,0x3a,0x8b,0xae,0x81,0x46,0xa8,0xf1,0x83,0xcb,
  0x44,0x15,0x6,0xda,0x61,0x3,0x5a,0x8b,0xd0,0x84,0x42,0x34,0x17,0x61,0x3a,0xc0,
  0x84,0x1c,0x77,0xb1,0x5b,0x87,0x5c,0x22,0x19,0x92,0xd7,0x3f,0x5b,0xcd,0x21,0x4b,
  0xb9,0x98,0xb5,0x4e,0xf0,0x17,0xbb,0xca,0xe1,0x82,0x49,0xd3,0xc,0xea,0xb5,0x66,
  0xc2,0x4d,0x26,0xd8,0x93,0x20,0xdc,0xbc,0x9d,0xe0,0x97,0xdb,0x66,0x30,0x8f,0x35,
  0x83,0x39,0x6a,0x3,0x5d,0xf,0x85,0x6f,0x4a,0xaa,0xbf,0x93,0x9d,0x62,0x83,0x7f,
  0x69,0x3c,0x6a,0x3e,0x5c,0x8f,0x76,0xd1,0xd,0xf6,0x5f,0xb1,0xc7,0xdc,0x1a,0xab,
  0x91,0xa5,0x70,0x45,0x2f,0xdc,0x35,0x43,0xb3,0x42,0xb4,0x49,0xf2,0x5f,0x93,0xac,
  0x19,0xab,0x75,0xca,0x4d,0xba,0xd7,0x92,0x6e,0xf5,0xb8,0xae,0x52,0xbd,0x86,0x34,
  0xc1,0xd3,0x7f,0x16,0xbf,0x1,0xfd,0x7f,0xbd,0x50,
  
};

static const unsigned char qt_resource_name[] = {
  // qt-project.org
  0x0,0xe,
  0x5,0x28,0x6c,0x87,
  0x0,0x71,
  0x0,0x74,0x0,0x2d,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,0x6a,0x0,0x65,0x0,0x63,0x0,0x74,0x0,0x2e,0x0,0x6f,0x0,0x72,0x0,0x67,
    // propertyeditor
  0x0,0xe,
  0xd,0x76,0x85,0xe2,
  0x0,0x70,
  0x0,0x72,0x0,0x6f,0x0,0x70,0x0,0x65,0x0,0x72,0x0,0x74,0x0,0x79,0x0,0x65,0x0,0x64,0x0,0x69,0x0,0x74,0x0,0x6f,0x0,0x72,
    // fontmapping.xml
  0x0,0xf,
  0x7,0x30,0xe4,0x7c,
  0x0,0x66,
  0x0,0x6f,0x0,0x6e,0x0,0x74,0x0,0x6d,0x0,0x61,0x0,0x70,0x0,0x70,0x0,0x69,0x0,0x6e,0x0,0x67,0x0,0x2e,0x0,0x78,0x0,0x6d,0x0,0x6c,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor
  0x0,0x0,0x0,0x22,0x0,0x2,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x3,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
  // :/qt-project.org/propertyeditor/fontmapping.xml
  0x0,0x0,0x0,0x44,0x0,0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x1,0x5f,0x9a,0xa1,0x2d,0x18,

};

#ifdef QT_NAMESPACE
#  define QT_RCC_PREPEND_NAMESPACE(name) ::QT_NAMESPACE::name
#  define QT_RCC_MANGLE_NAMESPACE0(x) x
#  define QT_RCC_MANGLE_NAMESPACE1(a, b) a##_##b
#  define QT_RCC_MANGLE_NAMESPACE2(a, b) QT_RCC_MANGLE_NAMESPACE1(a,b)
#  define QT_RCC_MANGLE_NAMESPACE(name) QT_RCC_MANGLE_NAMESPACE2( \
        QT_RCC_MANGLE_NAMESPACE0(name), QT_RCC_MANGLE_NAMESPACE0(QT_NAMESPACE))
#else
#   define QT_RCC_PREPEND_NAMESPACE(name) name
#   define QT_RCC_MANGLE_NAMESPACE(name) name
#endif

#ifdef QT_NAMESPACE
namespace QT_NAMESPACE {
#endif

bool qRegisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

bool qUnregisterResourceData(int, const unsigned char *, const unsigned char *, const unsigned char *);

#ifdef QT_NAMESPACE
}
#endif

int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)()
{
    QT_RCC_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)();
int QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)()
{
    QT_RCC_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x2, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

namespace {
   struct initializer {
       initializer() { QT_RCC_MANGLE_NAMESPACE(qInitResources_propertyeditor)(); }
       ~initializer() { QT_RCC_MANGLE_NAMESPACE(qCleanupResources_propertyeditor)(); }
   } dummy;
}
